#!/bin/bash

### CONFIGURATION

SERVERID=""
SERVERKEY=""

TCPPORT="9113"
TLSPORT="9114"

IPV6=0
LOG=0
TLS=0
LOGDEBUG=0
LISTENIP=""

### DO NOT MODIFY BELOW

SCRIPT=`readlink -f $0`
WPATH=`dirname $SCRIPT`

PYV=`python3 -V 2>&1`
if [[ ${PYV} != *"3."* ]]; then
  echo "Python 3.x is required. Exiting..."
  exit;
fi

PYSV=`python3 -c 'import sys; print(sys.version_info[1])'`
PYSVV=`python3 -c 'import sys; print(sys.version_info[2])'`
if [ ${PYSV} -lt 2 ] || [ ${PYSV} -gt 10 ]; then
  echo "Python 3.2-3.9 is supported. This is 3.${PYSV}. Exiting..."
  sleep 1
  exit;
fi

PYOSSL="$(python3 -c 'from OpenSSL import SSL' 2>&1 | head -c 1)"
if [ ! -e ${PYOSSL} ]; then
  echo "Python OpenSSL (pyOpenSSL) is required. Exiting..."
  sleep 1
  exit;
fi

if [ ${PYSV} -eq 5 ] && [ ${PYSVV} -lt 3 ]; then
  VV="2"
else
  VV=""
fi


case "$2" in
    dev)   
	BINARY="bin/fireprobe.py" 
	;;
    *)
	BINARY="bin/fireprobe.cpython-3${PYSV}${VV}.pyc"
	;;
esac

if [ ${IPV6} == "1" ]; then
    EV6="-v6 1"
else
    EV6=""
fi

if [ ${TLS} == "1" ]; then
    if [ ${PYSV} -lt 4 ]; then
	echo "Python 3.${PYSV} does not support TLS 1.2. This may impact on TLS efficiency. Consider Python upgrade"
    fi
    ETLS="-s 1 -ps ${TLSPORT}"
else
    ETLS=""
fi

if [ ${LOG} == "1" ]; then
    ELOG="-l 1 -lf 1 -ln ${WPATH}/log/fireprobe.log -ld ${LOGDEBUG}"
else
    ELOG="-l 0"
fi

if [ ! -e ${SERVERID} ]; then
    ESRVID="--serverid ${SERVERID}"
else
    ESRVID=""
fi

if [ ! -e ${SERVERKEY} ]; then
    ESRVKEY="--serverkey ${SERVERKEY}"
else
    ESRVKEY=""
fi

if [ ! -e ${LISTENIP} ]; then
    ELIP="-i ${LISTENIP}"
else
    ELIP=""
fi

startme() {

    PIDNO=`ps x | grep "python3 ${WPATH}/${BINARY}" | grep -v "grep" | awk '{print $1}'`
    kill -9 ${PIDNO} 1> /dev/null 2> /dev/null

    echo "Starting FIREPROBE server..."
    python3 ${WPATH}/${BINARY} -d 1 -p ${TCPPORT} ${EV6} ${ETLS} ${ELOG} ${ESRVID} ${ESRVKEY} ${ELIP} 1> /dev/null 2> /dev/null
    PIDNO=`ps x | grep "python3 ${WPATH}/${BINARY}" | grep -v "grep" | awk '{print $1}'`
    if [ ! -e ${PIDNO} ]; then
	echo "FIREPROBE server started (PID: ${PIDNO})"
    else
	echo "FIREPROBE server not started"
    fi
    sleep 1

}

stopme() {

    PIDNO=`ps x | grep "python3 ${WPATH}/${BINARY}" | grep -v "grep" | awk '{print $1}'`
    if [ ! -e ${PIDNO} ]; then
	echo "Stoping FIREPROBE server (PID: ${PIDNO})..."
        kill -9 ${PIDNO} 1> /dev/null 2> /dev/null
	echo "FIREPROBE server stoped."
	sleep 1
    else 
	echo "FIREPROBE server not running."
    fi
    sleep 1

}

case "$1" in
    start)   startme ;;
    stop)    stopme ;;
    restart) stopme; startme ;;
    *) echo "usage: $0 start|stop|restart" >&2
       exit 1
       ;;
esac
